@@ -6,9 +6,9 @@ Type annotations for chime-sdk-meetings service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_meetings.literals import TranscribeContentIdentificationTypeType
+    from mypy_boto3_chime_sdk_meetings.literals import MeetingFeatureStatusType
 
-    data: TranscribeContentIdentificationTypeType = "PII"
+    data: MeetingFeatureStatusType = "AVAILABLE"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "MeetingFeatureStatusType",
     "TranscribeContentIdentificationTypeType",
     "TranscribeContentRedactionTypeType",
     "TranscribeLanguageCodeType",
@@ -35,6 +36,7 @@ __all__ = (
 )
 
 
+MeetingFeatureStatusType = Literal["AVAILABLE", "UNAVAILABLE"]
 TranscribeContentIdentificationTypeType = Literal["PII"]
 TranscribeContentRedactionTypeType = Literal["PII"]
 TranscribeLanguageCodeType = Literal[
@@ -85,6 +87,7 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
@@ -104,6 +107,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -180,6 +184,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -206,6 +211,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -219,6 +225,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -264,6 +271,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -294,6 +302,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -309,6 +318,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -366,5 +376,6 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
